# Frequently Asked Questions

## Why do we need spyral-utils?

Spyral is a big libray that does a lot of things. It also has many dependencies outside of the ones used here. To make everyone's life easier, we extracted some of the most portable, and most requested functionality to an independent package.

## Why doesn't spyral-utils have feature x-y-z?

spyral-utils needs to be fully compatible with Spyral's goals. It should be cross-platform, and support a minimum Python version of 3.10. These requirements alone can eliminate a lot of tools! But, usually the reason is we just haven't thought of it yet. If you have an idea of a useful tool to add to spyral-utils please see the [For Developers](for_devs.md) section and submit a pull request or open an issue on GitHub!
